@@ -62,8 +62,17 @@ mod tests {
             application_command::{CommandData, CommandInteractionDataResolved, InteractionMember},
             ApplicationCommand, InteractionType,
         },
+        channel::{
+            message::{
+                sticker::{MessageSticker, StickerFormatType, StickerId},
+                MessageFlags, MessageType,
+            },
+            Message,
+        },
         guild::{PartialMember, Permissions, Role},
-        id::{ApplicationId, ChannelId, CommandId, GuildId, InteractionId, RoleId, UserId},
+        id::{
+            ApplicationId, ChannelId, CommandId, GuildId, InteractionId, MessageId, RoleId, UserId,
+        },
         user::User,
     };
 
@@ -80,15 +89,74 @@ mod tests {
                     options: Vec::new(),
                     resolved: Some(CommandInteractionDataResolved {
                         channels: Vec::new(),
-                        members: vec![InteractionMember {
+                        members: Vec::from([InteractionMember {
                             hoisted_role: None,
                             id: UserId(7),
                             joined_at: Some("joined at date".into()),
                             nick: None,
                             premium_since: None,
                             roles: vec![RoleId(8)],
-                        }],
-                        roles: vec![Role {
+                        }]),
+                        messages: Vec::from([Message {
+                            activity: None,
+                            application: None,
+                            application_id: None,
+                            attachments: Vec::new(),
+                            author: User {
+                                accent_color: None,
+                                avatar: Some("aaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa".to_owned()),
+                                banner: None,
+                                bot: false,
+                                discriminator: "0001".to_owned(),
+                                email: None,
+                                flags: None,
+                                id: UserId(3),
+                                locale: None,
+                                mfa_enabled: None,
+                                name: "test".to_owned(),
+                                premium_type: None,
+                                public_flags: None,
+                                system: None,
+                                verified: None,
+                            },
+                            channel_id: ChannelId(2),
+                            components: Vec::new(),
+                            content: "ping".to_owned(),
+                            edited_timestamp: None,
+                            embeds: Vec::new(),
+                            flags: Some(MessageFlags::empty()),
+                            guild_id: Some(GuildId(1)),
+                            id: MessageId(4),
+                            interaction: None,
+                            kind: MessageType::Regular,
+                            member: Some(PartialMember {
+                                deaf: false,
+                                joined_at: Some("2020-01-01T00:00:00.000000+00:00".to_owned()),
+                                mute: false,
+                                nick: Some("member nick".to_owned()),
+                                permissions: None,
+                                premium_since: None,
+                                roles: Vec::new(),
+                                user: None,
+                            }),
+                            mention_channels: Vec::new(),
+                            mention_everyone: false,
+                            mention_roles: Vec::new(),
+                            mentions: Vec::new(),
+                            pinned: false,
+                            reactions: Vec::new(),
+                            reference: None,
+                            sticker_items: vec![MessageSticker {
+                                format_type: StickerFormatType::Png,
+                                id: StickerId(1),
+                                name: "sticker name".to_owned(),
+                            }],
+                            referenced_message: None,
+                            timestamp: "2020-02-02T02:02:02.020000+00:00".to_owned(),
+                            tts: false,
+                            webhook_id: None,
+                        }]),
+                        roles: Vec::from([Role {
                             color: 0u32,
                             hoist: false,
                             id: RoleId(8),
@@ -98,9 +166,11 @@ mod tests {
                             permissions: Permissions::empty(),
                             position: 2i64,
                             tags: None,
-                        }],
-                        users: vec![User {
+                        }]),
+                        users: Vec::from([User {
+                            accent_color: None,
                             avatar: Some("different avatar".into()),
+                            banner: None,
                             bot: false,
                             discriminator: "5678".into(),
                             email: None,
@@ -113,7 +183,7 @@ mod tests {
                             public_flags: None,
                             system: None,
                             verified: None,
-                        }],
+                        }]),
                     }),
                 },
                 guild_id: Some(GuildId(3)),
@@ -128,7 +198,9 @@ mod tests {
                     premium_since: None,
                     roles: Vec::new(),
                     user: Some(User {
+                        accent_color: None,
                         avatar: Some("avatar string".into()),
+                        banner: None,
                         bot: false,
                         discriminator: "1234".into(),
                         email: None,
