@@ -293,7 +293,9 @@ mod tests {
                 premium_since: None,
                 roles: Vec::new(),
                 user: User {
+                    accent_color: None,
                     avatar: Some("".to_owned()),
+                    banner: None,
                     bot: false,
                     discriminator: "0001".to_owned(),
                     email: None,
@@ -323,8 +325,8 @@ mod tests {
 
         assert_eq!(cache.0.members.len(), 1);
         {
-            let entry = cache.0.users.get(&UserId(3)).unwrap();
-            assert_eq!(entry.value().1.len(), 1);
+            let entry = cache.0.user_guilds.get(&UserId(3)).unwrap();
+            assert_eq!(entry.value().len(), 1);
         }
         assert_eq!(
             cache.member(GuildId(2), UserId(3)).unwrap().user_id,
